package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.service.IStatisticalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDate;
import java.util.Date;

/**
 * 数据统计
 */
@RestController
@RequestMapping("/api")
public class StatisticalController {

    @Autowired
    private IStatisticalService iStatisticalService;

    /**
     * 首页统计
     * @return
     */
    @GetMapping(value = "/admin/indexStatistical")
    public ResponseBean indexStatistical() {
        return iStatisticalService.indexStatistical();
    }

    /**
     * 活跃用户数
     * @return
     */
    @GetMapping(value = "/admin/selectActiveUserCount")
    public ResponseBean selectActiveUserCount(@RequestParam String dateType) {
        return iStatisticalService.selectActiveUserCount(dateType);
    }

    /**
     * 新增用户数
     * @return
     */
    @GetMapping(value = "/admin/selectNewsUserCount")
    public ResponseBean selectNewsUserCount(@RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                            @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate) {
        return iStatisticalService.selectNewsUserCount(startDate, endDate);
    }

    /**
     * 转化率 统计
     * @return
     */
    @GetMapping(value = "/admin/selectConversion")
    public ResponseBean selectConversion(@RequestParam("conversion") String conversion) {
        return iStatisticalService.selectConversion(conversion);
    }

    /**
     * 用户行为
     * @return
     */
    @GetMapping(value = "/admin/selectUserBehavior")
    public ResponseBean selectUserBehavior(@RequestParam(required = false) Integer pageNum,
                                           @RequestParam(required = false) Integer pageCode,
                                           @RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                           @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate) {
        return iStatisticalService.selectUserBehavior(pageNum, pageCode, startDate, endDate);
    }

    /**
     * 行为分析的 具体事件数据列表
     * @return
     */
    @GetMapping(value = "/admin/selectEventAll")
    public ResponseBean selectEventAll(@RequestParam(required = false) String event,
                                              @RequestParam(required = false) Integer personId) {
        return iStatisticalService.selectEventAll(event, personId);
    }


    /**
     * 用户来源
     * @return
     */
    @GetMapping(value = "/admin/selectUserResource")
    public ResponseBean selectUserResource(@RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                           @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate,
                                           @RequestParam(value = "registeredType", required = false) String registeredType) {
        return iStatisticalService.selectUserResource(startDate, endDate, registeredType);
    }



}
